@@ -47,7 +47,6 @@ def Seismic_SEL(data,rng,Fs,sens=1e5/19.7,plotFlag=True,logFlag=True):
     '''
     Calculate Sound Exposure Level from full array data
     '''
-    import xarray as xr
     
     if type(data) == np.ndarray:
         nrec = data.shape[0]
@@ -361,13 +360,8 @@ def time_stacking(nav,data,DATA,SSP,d_layer):
     # print(header.file_number)
     Fs = 500
     nfft = int(data.shape[1]) #int(nearest_pow_2(data.shape[0]))
-    time = np.linspace(0,(data.shape[0]-1)/Fs,data.shape[0])
     f = np.linspace(0,Fs,nfft)
 
-    # srcBath = nav.depth[ssp_i]
-    Time = str(header.hour)+':'+str(header.minute)+':'+str(header.second)
-    JulianDay = header.julian_day
-    Year = header.year
     receiver_no = data.shape[1]
     hydX = nav.receiverX[filenum][0:receiver_no]
     hydY = nav.receiverY[filenum][0:receiver_no]
@@ -382,8 +376,6 @@ def time_stacking(nav,data,DATA,SSP,d_layer):
     y_r = np.array(y_r)
     z_r = np.array(z_r)
     offset = np.sqrt(x_r**2 + y_r**2)
-
-    sos = np.array([[1,-2,1,1,-1.82570619168342,0.881881926844246],[1,-2,1,1,-1.65627993129105,0.707242535896459],[1,-2,1,1,-1.57205200320457,0.620422971870477]])
     
     # START SIMPLE AND ASSUME CONSTANT SSP
     # For loop over each receiver
@@ -443,7 +435,7 @@ def ref_coeff(data,offset,depth,Fs,spreadFlag = False, beamdata = False, c = 148
         
     samples = np.size(data,1)
     nrec = np.size(data,0)
-    angles = np.atan(2*depth/offset)
+    angles = np.arctan(2*depth/offset)
     freq_energy = np.zeros([nrec,samples])
     freq_direnergy = np.zeros([nrec,samples])
     freq_refenergy = np.zeros([nrec,samples])
@@ -461,7 +453,7 @@ def ref_coeff(data,offset,depth,Fs,spreadFlag = False, beamdata = False, c = 148
         angle_i2 = int((np.round(angle)+90)/2)
         
         # Calculate energy at each receiver/frequency
-        freq_energy = np.abs(np.fft.fft(data[i,:],samples,1))[0:int(samples/2)]
+        freq_energy = np.abs(np.fft.fft(data[i,:],samples))[0:int(samples/2)]
 
         # Calculate energy direct path
         t_delay = offset[i]/c
@@ -470,7 +462,7 @@ def ref_coeff(data,offset,depth,Fs,spreadFlag = False, beamdata = False, c = 148
         tsamp = ti[1]-ti[0]
         datatmp = np.append(data[i,ti[0]:ti[1]],np.zeros(samples-tsamp))
         beamtmp = np.interp(np.linspace(0,Fs/2,int(samples/2)), np.arange(0,Fs/2,1), beamdata[0,:])
-        freq_direnergy = np.abs(np.fft.fft(datatmp,tsamp,1))
+        freq_direnergy = np.abs(np.fft.fft(datatmp,tsamp))
 
         # Calculate energy first reflection
         t_delay = np.sqrt(offset[i]**2 + (2*depth)**2)/c
@@ -479,7 +471,7 @@ def ref_coeff(data,offset,depth,Fs,spreadFlag = False, beamdata = False, c = 148
         tsamp = ti[1]-ti[0]
         datatmp = np.append(data[i,ti[0]:ti[1]],np.zeros(samples-tsamp))
         beamtmp = np.interp(np.linspace(0,Fs/2,int(samples/2)), np.arange(0,Fs/2,1), beamdata[angle_i,:])
-        freq_refenergy = np.abs(np.fft.fft(datatmp,tsamp,1))
+        freq_refenergy = np.abs(np.fft.fft(datatmp,tsamp))
 
         # Calculate energy second reflection
         t_delay = np.sqrt(offset[i]**2 + (4*depth)**2)/c
@@ -488,7 +480,7 @@ def ref_coeff(data,offset,depth,Fs,spreadFlag = False, beamdata = False, c = 148
         tsamp = ti[1]-ti[0]
         datatmp = np.append(data[i,ti[0]:ti[1]],np.zeros(samples-tsamp))
         beamtmp = np.interp(np.linspace(0,Fs,tsamp), np.arange(0,Fs/2,Fs/2), beamdata[angle_i2,:])
-        freq_ref2energy = np.abs(np.fft.fft(datatmp,tsamp,1))
+        freq_ref2energy = np.abs(np.fft.fft(datatmp,tsamp))
 
         if spreadFlag == True:
             freq_direnergy = freq_direnergy*offset[i]
